
# Slot: retrievedOn




URI: [biolink:retrievedOn](https://w3id.org/biolink/vocab/retrievedOn)

## Domain and Range

[SourceFile](SourceFile.md) ->  <sub>OPT</sub> [Date](Date.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [SourceFile](SourceFile.md)
